@@ -24,6 +24,7 @@
 #include "Session.h"
 #include "SessionDisplayConnection.h"
 #include "ViewProperties.h"
+#include "konsoleprivate_export.h"
 
 class QAction;
 class QTextCodec;
@@ -65,7 +66,7 @@ class HotSpot;
  * which contains the view to plug the controller's actions into the menu when
  * the view is focused.
  */
-class KONSOLESESSION_EXPORT SessionController : public ViewProperties, public KXMLGUIClient
+class KONSOLEPRIVATE_EXPORT SessionController : public ViewProperties, public KXMLGUIClient
 {
     Q_OBJECT
 
@@ -143,6 +144,9 @@ public:
     bool isReadOnly() const;
     bool isCopyInputActive() const;
 
+    /* Set/reset selection mode */
+    void setSelectMode(bool mode);
+
 Q_SIGNALS:
     /**
      * Emitted when the view associated with the controller is focused.
@@ -153,6 +157,13 @@ Q_SIGNALS:
 
     void rawTitleChanged();
 
+    /*
+     * Emitted when the user requests to split the view from the context menu.
+     */
+
+    void requestSplitViewLeftRight();
+    void requestSplitViewTopBotton();
+
     /**
      * Emitted when the current working directory of the session associated with
      * the controller is changed.
