@@ -41,6 +41,7 @@ class QTimerEvent;
 class QScrollEvent;
 class QScrollPrepareEvent;
 class KMessageWidget;
+class QMimeData;
 
 struct UBiDi;
 
@@ -161,8 +162,10 @@ public:
      * Sets the Cursor Style (DECSCUSR) via escape sequences
      * @p shape cursor shape
      * @p isBlinking if true, the cursor will be set to blink
+     * @p customColor custom cursor color
      */
-    void setCursorStyle(Enum::CursorShapeEnum shape, bool isBlinking);
+    void setCursorStyle(Enum::CursorShapeEnum shape, bool isBlinking, const QColor &customColor);
+
     /**
      * Resets the cursor style to the current profile cursor shape and
      * blinking settings
@@ -399,7 +402,7 @@ public:
 
     bool getReadOnly() const
     {
-        return _readOnly;
+        return _readOnly || _selectMode;
     }
 
     // Get mapping between visual and logical positions in line
@@ -430,7 +433,7 @@ public Q_SLOTS:
     void updateImage();
 
     /** Copies the selected text to the X11 Selection. */
-    void copyToX11Selection();
+    void copyToX11Selection(bool useSavedText = false);
 
     /** Copies the selected text to the system clipboard. */
     void copyToClipboard(Screen::DecodingOptions options = Screen::PlainText);
@@ -582,7 +585,7 @@ protected:
     void clearImage();
 
     void mouseTripleClickEvent(QMouseEvent *ev);
-    void selectLine(QPoint pos, bool entireLine);
+    void selectLine(QPoint pos, bool entireLine, bool fromTripleClick = false);
 
     // reimplemented
     void inputMethodEvent(QInputMethodEvent *event) override;
@@ -656,6 +659,9 @@ private:
      */
     void setCenterContents(bool enable);
 
+    // Clear _screenWindow selection and also pending double click selection
+    void clearSelection();
+
     // the window onto the terminal screen which this display
     // is currently showing.
     QPointer<ScreenWindow> _screenWindow;
@@ -730,8 +736,12 @@ private:
     bool _dropUrlsAsText = false; // always paste URLs as text without showing copy/move menu
 
     Enum::TripleClickModeEnum _tripleClickMode = Enum::SelectWholeLine;
-    bool _possibleTripleClick = false; // is set in mouseDoubleClickEvent and deleted
-    // after QApplication::doubleClickInterval() delay
+    bool _possibleTripleClick = false; // is set in mouseDoubleClickEvent and cleared
+                                       // after QApplication::doubleClickInterval() delay
+    QPoint _tripleClickPos; // The position where a potential triple click was started
+    QString _doubleClickSelectedText; // selected text whose copying may be cancelled by further events; copying
+    QString _doubleClickSelectedHtml; // is delayed to prevent a triple-click from generating > 1 entries in the
+                                      // clipboard history (a triple click is a double click at first ;)
 
     QLabel *_resizeWidget = nullptr;
     QTimer *_resizeTimer = nullptr;
@@ -775,6 +785,7 @@ private:
 
     // Needed to know whether the mode really changed between update calls
     bool _readOnly = false;
+    bool _selectMode = false;
 
     bool _dimWhenInactive = false;
     int _dimValue;
